# tibber-pyAws
AWS related packages.
Built using GitHub Actions and releases created from GitHub and pushed to pypi.

## Packages
* `tibber_aws` - Communication with AWS

## Create Release
* Update version in setup.py
* Create a [Release](https://github.com/tibbercom/tibber-pyAws/releases)
  This will push the package to pypi.
